@@ -5,7 +5,7 @@ Lazy::Utils - Utilities for lazy
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -28,7 +28,7 @@ BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.02';
+	our $VERSION     = '1.03';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
@@ -42,19 +42,13 @@ BEGIN
 
 =cut
 
-=head3 trim
+=head3 trim($str)
 
 trims given string
 
-=over
+$str: I<string will be trimed>
 
-trim($str)
-
-B<$str:> string will be trimed
-
-B<return value:> trimed string
-
-=back
+return value: I<trimed string>
 
 =cut
 sub trim
@@ -64,19 +58,13 @@ sub trim
 	return $s
 }
 
-=head3 ltrim
+=head3 ltrim($str)
 
 trims left given string
 
-=over
+$str: I<string will be trimed>
 
-ltrim($str)
-
-B<$str:> string will be trimed
-
-B<return value:> trimed string
-
-=back
+return value: I<trimed string>
 
 =cut
 sub ltrim
@@ -86,19 +74,13 @@ sub ltrim
 	return $s
 }
 
-=head3 rtrim
+=head3 rtrim($str)
 
 trims right given string
 
-=over
+$str: I<string will be trimed>
 
-rtrim($str)
-
-B<$str:> string will be trimed
-
-B<return value:> trimed string
-
-=back
+return value: I<trimed string>
 
 =cut
 sub rtrim
@@ -108,19 +90,13 @@ sub rtrim
 	return $s
 }
 
-=head3 file_get_contents
+=head3 file_get_contents($path)
 
-get all contents of file, by string type
+gets all contents of file in string type
 
-=over
+$path: I<path of file>
 
-file_get_contents($path)
-
-B<$path:> path of file
-
-B<return value:> file contents by string type
-
-=back
+return value: I<file contents in string type>
 
 =cut
 sub file_get_contents
@@ -137,19 +113,13 @@ sub file_get_contents
 	return $document;
 }
 
-=head3 shellmeta
+=head3 shellmeta($s)
 
-escape metacharacters for double-quoted shell string
+escapes metacharacters of double-quoted shell string
 
-=over
+$s: I<double-quoted shell string>
 
-shellmeta($s)
-
-B<$s:> double-quoted shell string
-
-B<return value:> escaped string
-
-=back
+return value: I<escaped string>
 
 =cut
 sub shellmeta
@@ -160,25 +130,19 @@ sub shellmeta
 	return $s;
 }
 
-=head3 _system
+=head3 _system($cmd, @argv)
 
 executes a system command like Perl system call
 
-=over
+$cmd: I<command>
 
-_system($cmd, @argv)
+@argv: I<command line arguments>
 
-B<$cmd:> command
+return value: I<exit code of command. 511 if fatal error occurs>
 
-B<@argv:> command line arguments
+returned $?: I<return code of wait call like on Perl system call>
 
-B<return value:> exit code of command. 511 if fatal error occurs
-
-B<returned $?:> return code of wait call, like Perl system call
-
-B<returned $!:> system error message, like Perl system call
-
-=back
+returned $!: I<system error message like on Perl system call>
 
 =cut
 sub _system
@@ -201,19 +165,13 @@ sub _system
 	return $? >> 8;
 }
 
-=head3 bashReadLine
+=head3 bashReadLine($prompt)
 
 reads a line using bash
 
-=over
+$prompt: I<prompt>
 
-bashReadLine($prompt)
-
-B<$prompt:> prompt
-
-B<return value:> line
-
-=back
+return value: I<line>
 
 =cut
 sub bashReadLine
@@ -230,19 +188,13 @@ sub bashReadLine
 	return (not $?)? $_: undef;
 }
 
-=head3 cmdArgs
+=head3 cmdArgs(@argv)
 
 resolves command line arguments, eg: -opt1 --opt2 val2 command_string parameter1 parameter2 ...
 
-=over
+@argv: I<command line arguments>
 
-cmdArgs(@argv)
-
-B<@argv:> command line arguments
-
-B<return value:> { -opt1 => 'opt1', --opt2 => 'val2', command => 'command_string', parameters => ['parameter1', 'parameter2', ...] }
-
-=back
+return value: I<{ -opt1 =E<gt> 'opt1', --opt2 =E<gt> 'val2', command =E<gt> 'command_string', parameters =E<gt> ['parameter1', 'parameter2', ...] }>
 
 =cut
 sub cmdArgs
